@@ -1,7 +1,7 @@
 import sys
 import tomli
-import argparse
 from schema_compare.drivers.postgresql.connection import Connection
+import schema_compare
 
 def main():
     if len(sys.argv) < 2:
@@ -32,20 +32,10 @@ def main():
     print(result)
     print(f"Target schema has less {len(result)} (table_name,column_name) than source schema")
     result = result.to_html()
-
-    if len(sys.argv) == 3:
-        #TODO - use argparse...
-        print("Generating report")
-        import os
-        absolute_path = os.path.dirname(__file__)
-        relative_path = "report.html"
-        full_path = os.path.join(absolute_path, relative_path)
-        f = open(full_path,"r")
-        content = f.read()
-        output = open("/output.html","w")
-        output.write(content.replace("{{body}}",result))
-        output.close()
-        f.close()
+    print("Generating report")
+    output = open("/output.html","w")
+    output.write(schema_compare.TEMPLATE.replace("{{body}}",result))
+    output.close()
 
 if __name__ == "__main__":
     main()
